@@ -27,7 +27,9 @@
                            'ggname','ggplot_gtable','camelize',
                            'element_grob.element_line','element_grob.element_rect','element_grob.element_text','element_grob.element_blank',
                            'plot_clone','compute_just','labelGrob',
-                           'hexGrob','try_require','hex_binwidth','hexBinSummarise',
+                           'hexGrob',
+                           # 'try_require', ## REMOVED
+                           'hex_binwidth','hexBinSummarise',
                            'find_args','is.margin','justify_grobs')
   .functions.gridExtra  = c('latticeGrob')
     .functions          = rbind(data.frame(p='ggplot2',  f=unique(.functions.ggplot2)),
