@@ -67,7 +67,7 @@ rd_aesthetics <- function(type, name) {
   paste("\\code{", type, "_", name, "} ",
         "understands the following aesthetics (required aesthetics are in bold):\n\n",
         "\\itemize{\n",
-        paste("  \\item \\code{", aes, "}", collapse = "\n", sep = ""),
+        paste("  \\item ", aes, collapse = "\n", sep = ""),
         "\n}\n", sep = "")
 }
 
